@@ -4,29 +4,31 @@ build_time_vars = {'ABIFLAGS': '',
  'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
  'ALIGNOF_LONG': 4,
+ 'ALIGNOF_MAX_ALIGN_T': 8,
  'ALIGNOF_SIZE_T': 4,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
  'AR': 'ar',
  'ARFLAGS': 'rcs',
- 'BASECFLAGS': '',
+ 'BASECFLAGS': '-fno-strict-overflow',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/bin',
- 'BINLIBDEST': '/usr/lib/python3.11',
- 'BLDLIBRARY': '-L. -lpython3.11',
+ 'BINLIBDEST': '/usr/lib/python3.12',
+ 'BLDLIBRARY': '-L. -lpython3.12',
  'BLDSHARED': 'gcc -shared -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
               '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'BOOTSTRAP_HEADERS': '\\',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'BUILD_GNU_TYPE': 'armv7l-unknown-linux-gnueabihf',
+ 'BUILD_SCRIPTS_DIR': 'build/scripts-3.12',
  'BYTESTR_DEPS': '\\',
  'CC': 'gcc',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-DNDEBUG -g -fwrapv -O3 -Wall -march=armv7-a -mfloat-abi=hard '
-           '-mfpu=neon -O3 -pipe -fstack-protector-strong -fno-plt '
-           '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+ 'CFLAGS': '-fno-strict-overflow -DNDEBUG -g -O3 -Wall -march=armv7-a '
+           '-mfloat-abi=hard -mfpu=neon -O3 -pipe -fstack-protector-strong '
+           '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
            '-Werror=format-security         -fstack-clash-protection '
            '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
            '-fstack-protector-strong -fno-plt -fexceptions         '
@@ -38,6 +40,9 @@ build_time_vars = {'ABIFLAGS': '',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
+ 'CODECS_COMMON_HEADERS': './Modules/cjkcodecs/multibytecodec.h '
+                          './Modules/cjkcodecs/cjkcodecs.h',
+ 'COMPILEALL_OPTS': '-j0',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
@@ -62,27 +67,25 @@ build_time_vars = {'ABIFLAGS': '',
                 "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now' "
                 "'CPPFLAGS='",
  'CONFINCLUDEDIR': '/usr/include',
- 'CONFINCLUDEPY': '/usr/include/python3.11',
+ 'CONFINCLUDEPY': '/usr/include/python3.12',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/python/src/Python-3.11.8/coverage.info',
+ 'COVERAGE_INFO': '/build/python/src/Python-3.12.3/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/build/python/src/Python-3.11.8/lcov-report',
+ 'COVERAGE_REPORT': '/build/python/src/Python-3.12.3/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
-                            '--title "CPython 3.11 LCOV report [commit $(shell '
+                            '--title "CPython 3.12 LCOV report [commit $(shell '
                             ')]"',
  'CPPFLAGS': '-I. -I./Include',
  'CXX': 'g++',
- 'DECIMAL_CFLAGS': '-DCONFIG_32=1 -DANSI=1',
- 'DECIMAL_LDFLAGS': '-lmpdec',
  'DEEPFREEZE_C': 'Python/deepfreeze/deepfreeze.c',
- 'DEEPFREEZE_DEPS': './Tools/scripts/deepfreeze.py _bootstrap_python '
+ 'DEEPFREEZE_DEPS': './Tools/build/deepfreeze.py _bootstrap_python '
                     './Programs/_freeze_module.py \\',
  'DEEPFREEZE_OBJS': 'Python/deepfreeze/deepfreeze.o',
- 'DESTDIRS': '/usr /usr/lib /usr/lib/python3.11 '
-             '/usr/lib/python3.11/lib-dynload',
- 'DESTLIB': '/usr/lib/python3.11',
+ 'DESTDIRS': '/usr /usr/lib /usr/lib/python3.12 '
+             '/usr/lib/python3.12/lib-dynload',
+ 'DESTLIB': '/usr/lib/python3.12',
  'DESTPATH': '',
- 'DESTSHARED': '/usr/lib/python3.11/lib-dynload',
+ 'DESTSHARED': '/usr/lib/python3.12/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
  'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
@@ -95,6 +98,8 @@ build_time_vars = {'ABIFLAGS': '',
  'DOUBLE_IS_ARM_MIXED_ENDIAN_IEEE754': 0,
  'DOUBLE_IS_BIG_ENDIAN_IEEE754': 0,
  'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 1,
+ 'DSYMUTIL': '',
+ 'DSYMUTIL_PATH': '',
  'DTRACE': '',
  'DTRACE_DEPS': '\\',
  'DTRACE_HEADERS': '',
@@ -104,12 +109,11 @@ build_time_vars = {'ABIFLAGS': '',
  'ENSUREPIP': 'no',
  'EXE': '',
  'EXEMODE': 755,
- 'EXPAT_CFLAGS': '',
- 'EXPAT_LDFLAGS': '-lexpat',
+ 'EXENAME': '/usr/bin/python3.12',
  'EXPORTSFROM': '',
  'EXPORTSYMS': '',
  'EXTRATESTOPTS': '',
- 'EXT_SUFFIX': '.cpython-311-arm-linux-gnueabihf.so',
+ 'EXT_SUFFIX': '.cpython-312-arm-linux-gnueabihf.so',
  'FILEMODE': 644,
  'FLOAT_WORDS_BIGENDIAN': 0,
  'FREEZE_MODULE': './_bootstrap_python ./Programs/_freeze_module.py',
@@ -203,6 +207,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_DUP3': 1,
  'HAVE_DYLD_SHARED_CACHE_CONTAINS_PATH': 0,
  'HAVE_DYNAMIC_LOADING': 1,
+ 'HAVE_EDITLINE_READLINE_H': 0,
  'HAVE_ENDIAN_H': 1,
  'HAVE_EPOLL': 1,
  'HAVE_EPOLL_CREATE1': 1,
@@ -225,6 +230,9 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_FDOPENDIR': 1,
  'HAVE_FDWALK': 0,
  'HAVE_FEXECVE': 1,
+ 'HAVE_FFI_CLOSURE_ALLOC': 1,
+ 'HAVE_FFI_PREP_CIF_VAR': 1,
+ 'HAVE_FFI_PREP_CLOSURE_LOC': 1,
  'HAVE_FLOCK': 1,
  'HAVE_FORK': 1,
  'HAVE_FORK1': 0,
@@ -322,11 +330,8 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LIBDB': 1,
  'HAVE_LIBDL': 1,
  'HAVE_LIBDLD': 0,
- 'HAVE_LIBGDBM_COMPAT': 1,
  'HAVE_LIBIEEE': 0,
  'HAVE_LIBINTL_H': 1,
- 'HAVE_LIBNDBM': 0,
- 'HAVE_LIBREADLINE': 1,
  'HAVE_LIBRESOLV': 0,
  'HAVE_LIBSENDFILE': 0,
  'HAVE_LIBSQLITE3': 1,
@@ -340,6 +345,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LINUX_CAN_RAW_FD_FRAMES': 1,
  'HAVE_LINUX_CAN_RAW_H': 1,
  'HAVE_LINUX_CAN_RAW_JOIN_FILTERS': 1,
+ 'HAVE_LINUX_FS_H': 1,
  'HAVE_LINUX_LIMITS_H': 1,
  'HAVE_LINUX_MEMFD_H': 1,
  'HAVE_LINUX_NETLINK_H': 1,
@@ -362,8 +368,8 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_MAKEDEV': 1,
  'HAVE_MBRTOWC': 1,
  'HAVE_MEMFD_CREATE': 1,
- 'HAVE_MEMORY_H': 1,
  'HAVE_MEMRCHR': 1,
+ 'HAVE_MINIX_CONFIG_H': 0,
  'HAVE_MKDIRAT': 1,
  'HAVE_MKFIFO': 1,
  'HAVE_MKFIFOAT': 1,
@@ -373,6 +379,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_MMAP': 1,
  'HAVE_MREMAP': 1,
  'HAVE_NANOSLEEP': 1,
+ 'HAVE_NCURSESW': 1,
  'HAVE_NCURSES_H': 1,
  'HAVE_NDBM_H': 1,
  'HAVE_NDIR_H': 0,
@@ -380,12 +387,14 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_NETDB_H': 1,
  'HAVE_NETINET_IN_H': 1,
  'HAVE_NETPACKET_PACKET_H': 1,
+ 'HAVE_NET_ETHERNET_H': 1,
  'HAVE_NET_IF_H': 1,
  'HAVE_NICE': 1,
  'HAVE_NON_UNICODE_WCHAR_T_REPRESENTATION': 0,
  'HAVE_OPENAT': 1,
  'HAVE_OPENDIR': 1,
  'HAVE_OPENPTY': 1,
+ 'HAVE_PANEL_H': 1,
  'HAVE_PATHCONF': 1,
  'HAVE_PAUSE': 1,
  'HAVE_PIPE': 1,
@@ -415,6 +424,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_PWRITE': 1,
  'HAVE_PWRITEV': 1,
  'HAVE_PWRITEV2': 1,
+ 'HAVE_READLINE_READLINE_H': 0,
  'HAVE_READLINK': 1,
  'HAVE_READLINKAT': 1,
  'HAVE_READV': 1,
@@ -453,6 +463,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SETITIMER': 1,
  'HAVE_SETJMP_H': 1,
  'HAVE_SETLOCALE': 1,
+ 'HAVE_SETNS': 1,
  'HAVE_SETPGID': 1,
  'HAVE_SETPGRP': 1,
  'HAVE_SETPRIORITY': 1,
@@ -491,8 +502,8 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_STATVFS': 1,
  'HAVE_STAT_TV_NSEC': 1,
  'HAVE_STAT_TV_NSEC2': 0,
- 'HAVE_STDARG_PROTOTYPES': 1,
  'HAVE_STDINT_H': 1,
+ 'HAVE_STDIO_H': 1,
  'HAVE_STDLIB_H': 1,
  'HAVE_STD_ATOMIC': 1,
  'HAVE_STRFTIME': 1,
@@ -576,6 +587,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_UNAME': 1,
  'HAVE_UNISTD_H': 1,
  'HAVE_UNLINKAT': 1,
+ 'HAVE_UNSHARE': 1,
  'HAVE_USABLE_WCHAR_T': 1,
  'HAVE_UTIL_H': 0,
  'HAVE_UTIMENSAT': 1,
@@ -605,32 +617,32 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE__GETPTY': 0,
  'HOSTRUNNER': '',
  'HOST_GNU_TYPE': 'armv7l-unknown-linux-gnueabihf',
- 'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.11 '
-                   '/usr/include/python3.11',
+ 'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.12 '
+                   '/usr/include/python3.12',
  'INCLUDEDIR': '/usr/include',
- 'INCLUDEPY': '/usr/include/python3.11',
+ 'INCLUDEPY': '/usr/include/python3.12',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 755',
- 'INSTSONAME': 'libpython3.11.so.1.0',
+ 'INSTSONAME': 'libpython3.12.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'g++ -shared',
  'LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
             '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'LDFLAGS_NODIST': '',
- 'LDLIBRARY': 'libpython3.11.so',
+ 'LDLIBRARY': 'libpython3.12.so',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'gcc -shared -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
              '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
- 'LDVERSION': '3.11',
+ 'LDVERSION': '3.12',
  'LIBC': '',
- 'LIBDEST': '/usr/lib/python3.11',
+ 'LIBDEST': '/usr/lib/python3.12',
  'LIBDIR': '/usr/lib',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
- 'LIBEXPAT_CFLAGS': '-DNDEBUG -g -fwrapv -O3 -Wall -march=armv7-a '
+ 'LIBEXPAT_CFLAGS': '-fno-strict-overflow -DNDEBUG -g -O3 -Wall -march=armv7-a '
                     '-mfloat-abi=hard -mfpu=neon -O3 -pipe '
                     '-fstack-protector-strong -fno-plt -fexceptions         '
                     '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
@@ -648,13 +660,33 @@ build_time_vars = {'ABIFLAGS': '',
                     '-fPIC -fPIC',
  'LIBEXPAT_HEADERS': '\\',
  'LIBEXPAT_OBJS': '\\',
- 'LIBFFI_INCLUDEDIR': '',
+ 'LIBHACL_CFLAGS': '-I./Modules/_hacl/include -D_BSD_SOURCE -D_DEFAULT_SOURCE '
+                   '-fno-strict-overflow -DNDEBUG -g -O3 -Wall -march=armv7-a '
+                   '-mfloat-abi=hard -mfpu=neon -O3 -pipe '
+                   '-fstack-protector-strong -fno-plt -fexceptions         '
+                   '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                   '-Werror=format-security         -fstack-clash-protection '
+                   '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
+                   '-fstack-protector-strong -fno-plt -fexceptions         '
+                   '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                   '-Werror=format-security         -fstack-clash-protection '
+                   '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
+                   '-fstack-protector-strong -fno-plt -fexceptions         '
+                   '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+                   '-Werror=format-security         -fstack-clash-protection '
+                   '-std=c11 -Werror=implicit-function-declaration '
+                   '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
+                   '-fPIC -fPIC',
+ 'LIBHACL_HEADERS': '\\',
+ 'LIBHACL_SHA2_A': 'Modules/_hacl/libHacl_Hash_SHA2.a',
+ 'LIBHACL_SHA2_HEADERS': '\\',
+ 'LIBHACL_SHA2_OBJS': '\\',
  'LIBM': '-lm',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
- 'LIBMPDEC_CFLAGS': '-DCONFIG_32=1 -DANSI=1 -DNDEBUG -g -fwrapv -O3 -Wall '
-                    '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
-                    '-fstack-protector-strong -fno-plt -fexceptions         '
-                    '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+ 'LIBMPDEC_CFLAGS': '-DCONFIG_32=1 -DANSI=1 -fno-strict-overflow -DNDEBUG -g '
+                    '-O3 -Wall -march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 '
+                    '-pipe -fstack-protector-strong -fno-plt '
+                    '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                     '-Werror=format-security         -fstack-clash-protection '
                     '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
                     '-fstack-protector-strong -fno-plt -fexceptions         '
@@ -672,18 +704,18 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
  'LIBPC': '/usr/lib/pkgconfig',
- 'LIBPL': '/usr/lib/python3.11/config-3.11-arm-linux-gnueabihf',
+ 'LIBPL': '/usr/lib/python3.12/config-3.12-arm-linux-gnueabihf',
  'LIBPYTHON': '',
- 'LIBRARY': 'libpython3.11.a',
- 'LIBRARY_DEPS': 'libpython3.11.a libpython3.11.so libpython3.so',
+ 'LIBRARY': 'libpython3.12.a',
+ 'LIBRARY_DEPS': 'libpython3.12.a libpython3.12.so libpython3.so',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': '-ldl',
  'LIBSUBDIRS': 'asyncio \\',
  'LINKCC': 'gcc',
  'LINKFORSHARED': '-Xlinker -export-dynamic',
- 'LINK_PYTHON_DEPS': 'libpython3.11.a libpython3.11.so libpython3.so',
- 'LINK_PYTHON_OBJS': '-L. -lpython3.11',
+ 'LINK_PYTHON_DEPS': 'libpython3.12.a libpython3.12.so libpython3.so',
+ 'LINK_PYTHON_OBJS': '-L. -lpython3.12',
  'LIPO_32BIT_FLAGS': '',
  'LIPO_INTEL64_FLAGS': '',
  'LLVM_PROF_ERR': 'no',
@@ -693,18 +725,32 @@ build_time_vars = {'ABIFLAGS': '',
  'LOCALMODLIBS': '',
  'MACHDEP': 'linux',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/usr/lib/python3.11',
+ 'MACHDESTLIB': '/usr/lib/python3.12',
  'MACOSX_DEPLOYMENT_TARGET': '',
- 'MAINCC': 'gcc',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 1,
  'MAKESETUP': './Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MKDIR_P': '/usr/bin/mkdir -p',
- 'MODBUILT_NAMES': 'atexit  faulthandler  posix  _signal  _tracemalloc  '
-                   '_codecs  _collections  errno  _io  itertools  _sre  '
-                   '_thread  time  _weakref  _abc  _functools  _locale  '
-                   '_operator  _stat  _symtable  pwd  xxsubtype',
+ 'MODBUILT_NAMES': 'array  _asyncio  _bisect  _contextvars  _csv  _heapq  '
+                   '_json  _lsprof  _opcode  _pickle  _queue  _random  '
+                   '_struct  _xxsubinterpreters  _xxinterpchannels  _zoneinfo  '
+                   'audioop  math  cmath  _statistics  _datetime  _decimal  '
+                   'binascii  _bz2  _lzma  zlib  _dbm  _gdbm  readline  _md5  '
+                   '_sha1  _sha2  _sha3  _blake2  pyexpat  _elementtree  '
+                   '_codecs_cn  _codecs_hk  _codecs_iso2022  _codecs_jp  '
+                   '_codecs_kr  _codecs_tw  _multibytecodec  unicodedata  '
+                   '_crypt  fcntl  grp  mmap  nis  ossaudiodev  '
+                   '_posixsubprocess  resource  select  _socket  spwd  syslog  '
+                   'termios  _posixshmem  _multiprocessing  _ctypes  _curses  '
+                   '_curses_panel  _sqlite3  _ssl  _hashlib  _uuid  _tkinter  '
+                   'xxsubtype  _xxtestfuzz  _testbuffer  _testinternalcapi  '
+                   '_testcapi  _testclinic  _testimportmultiple  '
+                   '_testmultiphase  _testsinglephase  _ctypes_test  '
+                   'xxlimited  xxlimited_35  atexit  faulthandler  posix  '
+                   '_signal  _tracemalloc  _codecs  _collections  errno  _io  '
+                   'itertools  _sre  _thread  time  _typing  _weakref  _abc  '
+                   '_functools  _locale  _operator  _stat  _symtable  pwd',
  'MODDISABLED_NAMES': '',
  'MODLIBS': '',
  'MODOBJS': 'Modules/atexitmodule.o  Modules/faulthandler.o  '
@@ -716,11 +762,25 @@ build_time_vars = {'ABIFLAGS': '',
             'Modules/_io/textio.o Modules/_io/stringio.o  '
             'Modules/itertoolsmodule.o  Modules/_sre/sre.o  '
             'Modules/_threadmodule.o  Modules/timemodule.o  '
-            'Modules/_weakref.o  Modules/_abc.o  Modules/_functoolsmodule.o  '
-            'Modules/_localemodule.o  Modules/_operator.o  Modules/_stat.o  '
-            'Modules/symtablemodule.o  Modules/pwdmodule.o  '
-            'Modules/xxsubtype.o',
- 'MODSHARED_NAMES': '',
+            'Modules/_typingmodule.o  Modules/_weakref.o  Modules/_abc.o  '
+            'Modules/_functoolsmodule.o  Modules/_localemodule.o  '
+            'Modules/_operator.o  Modules/_stat.o  Modules/symtablemodule.o  '
+            'Modules/pwdmodule.o',
+ 'MODSHARED_NAMES': 'array _asyncio _bisect _contextvars _csv _heapq _json '
+                    '_lsprof _opcode _pickle _queue _random _struct '
+                    '_xxsubinterpreters _xxinterpchannels _zoneinfo audioop '
+                    'math cmath _statistics _datetime _decimal binascii _bz2 '
+                    '_lzma zlib _dbm _gdbm readline _md5 _sha1 _sha2 _sha3 '
+                    '_blake2 pyexpat _elementtree _codecs_cn _codecs_hk '
+                    '_codecs_iso2022 _codecs_jp _codecs_kr _codecs_tw '
+                    '_multibytecodec unicodedata _crypt fcntl grp mmap nis '
+                    'ossaudiodev _posixsubprocess resource select _socket spwd '
+                    'syslog termios _posixshmem _multiprocessing _ctypes '
+                    '_curses _curses_panel _sqlite3 _ssl _hashlib _uuid '
+                    '_tkinter xxsubtype _xxtestfuzz _testbuffer '
+                    '_testinternalcapi _testcapi _testclinic '
+                    '_testimportmultiple _testmultiphase _testsinglephase '
+                    '_ctypes_test xxlimited xxlimited_35',
  'MODULE_ARRAY_STATE': 'yes',
  'MODULE_ATEXIT_LDFLAGS': '',
  'MODULE_AUDIOOP_LDFLAGS': '-lm',
@@ -731,6 +791,8 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE_CMATH_DEPS': './Modules/_math.h',
  'MODULE_CMATH_LDFLAGS': '-lm',
  'MODULE_CMATH_STATE': 'yes',
+ 'MODULE_DEPS_SHARED': 'Modules/config.c',
+ 'MODULE_DEPS_STATIC': 'Modules/config.c',
  'MODULE_ERRNO_LDFLAGS': '',
  'MODULE_FAULTHANDLER_LDFLAGS': '',
  'MODULE_FCNTL_LDFLAGS': '',
@@ -754,6 +816,9 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE_PYEXPAT_DEPS': '',
  'MODULE_PYEXPAT_LDFLAGS': '-lexpat',
  'MODULE_PYEXPAT_STATE': 'yes',
+ 'MODULE_READLINE_CFLAGS': '-D_DEFAULT_SOURCE',
+ 'MODULE_READLINE_LDFLAGS': '-lreadline',
+ 'MODULE_READLINE_STATE': 'yes',
  'MODULE_RESOURCE_STATE': 'yes',
  'MODULE_SELECT_STATE': 'yes',
  'MODULE_SPWD_STATE': 'yes',
@@ -766,7 +831,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE_UNICODEDATA_STATE': 'yes',
  'MODULE_XXLIMITED_35_STATE': 'yes',
  'MODULE_XXLIMITED_STATE': 'yes',
- 'MODULE_XXSUBTYPE_LDFLAGS': '',
+ 'MODULE_XXSUBTYPE_STATE': 'yes',
  'MODULE_ZLIB_CFLAGS': '',
  'MODULE_ZLIB_LDFLAGS': '-lz',
  'MODULE_ZLIB_STATE': 'yes',
@@ -794,12 +859,35 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__BZ2_CFLAGS': '',
  'MODULE__BZ2_LDFLAGS': '-lbz2',
  'MODULE__BZ2_STATE': 'yes',
+ 'MODULE__CODECS_CN_DEPS': './Modules/cjkcodecs/mappings_cn.h '
+                           './Modules/cjkcodecs/multibytecodec.h '
+                           './Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_CN_STATE': 'yes',
+ 'MODULE__CODECS_HK_DEPS': './Modules/cjkcodecs/mappings_hk.h  '
+                           './Modules/cjkcodecs/multibytecodec.h '
+                           './Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_HK_STATE': 'yes',
+ 'MODULE__CODECS_ISO2022_DEPS': './Modules/cjkcodecs/mappings_jisx0213_pair.h '
+                                './Modules/cjkcodecs/alg_jisx0201.h '
+                                './Modules/cjkcodecs/emu_jisx0213_2000.h '
+                                './Modules/cjkcodecs/multibytecodec.h '
+                                './Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_ISO2022_STATE': 'yes',
+ 'MODULE__CODECS_JP_DEPS': './Modules/cjkcodecs/mappings_jisx0213_pair.h '
+                           './Modules/cjkcodecs/alg_jisx0201.h '
+                           './Modules/cjkcodecs/emu_jisx0213_2000.h '
+                           './Modules/cjkcodecs/mappings_jp.h '
+                           './Modules/cjkcodecs/multibytecodec.h '
+                           './Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_JP_STATE': 'yes',
+ 'MODULE__CODECS_KR_DEPS': './Modules/cjkcodecs/mappings_kr.h '
+                           './Modules/cjkcodecs/multibytecodec.h '
+                           './Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_KR_STATE': 'yes',
  'MODULE__CODECS_LDFLAGS': '',
+ 'MODULE__CODECS_TW_DEPS': './Modules/cjkcodecs/mappings_tw.h '
+                           './Modules/cjkcodecs/multibytecodec.h '
+                           './Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_TW_STATE': 'yes',
  'MODULE__COLLECTIONS_LDFLAGS': '',
  'MODULE__CONTEXTVARS_STATE': 'yes',
@@ -807,11 +895,24 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__CRYPT_LDFLAGS': '-lcrypt',
  'MODULE__CRYPT_STATE': 'yes',
  'MODULE__CSV_STATE': 'yes',
+ 'MODULE__CTYPES_CFLAGS': '-fno-strict-overflow',
  'MODULE__CTYPES_DEPS': './Modules/_ctypes/ctypes.h',
+ 'MODULE__CTYPES_LDFLAGS': '-lffi -ldl',
+ 'MODULE__CTYPES_MALLOC_CLOSURE': '',
+ 'MODULE__CTYPES_STATE': 'yes',
  'MODULE__CTYPES_TEST_LDFLAGS': '-lm',
  'MODULE__CTYPES_TEST_STATE': 'yes',
+ 'MODULE__CURSES_CFLAGS': '-D_DEFAULT_SOURCE',
+ 'MODULE__CURSES_LDFLAGS': '-lncursesw',
+ 'MODULE__CURSES_PANEL_CFLAGS': '-D_DEFAULT_SOURCE  -D_DEFAULT_SOURCE',
+ 'MODULE__CURSES_PANEL_LDFLAGS': '-lpanelw -lncursesw',
+ 'MODULE__CURSES_PANEL_STATE': 'yes',
+ 'MODULE__CURSES_STATE': 'yes',
  'MODULE__DATETIME_LDFLAGS': '-lm',
  'MODULE__DATETIME_STATE': 'yes',
+ 'MODULE__DBM_CFLAGS': '-DUSE_NDBM',
+ 'MODULE__DBM_LDFLAGS': '-lgdbm_compat',
+ 'MODULE__DBM_STATE': 'yes',
  'MODULE__DECIMAL_CFLAGS': '-DCONFIG_32=1 -DANSI=1',
  'MODULE__DECIMAL_DEPS': './Modules/_decimal/docstrings.h',
  'MODULE__DECIMAL_LDFLAGS': '-lmpdec',
@@ -838,8 +939,12 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__LZMA_CFLAGS': '',
  'MODULE__LZMA_LDFLAGS': '-llzma',
  'MODULE__LZMA_STATE': 'yes',
- 'MODULE__MD5_DEPS': './Modules/hashlib.h',
+ 'MODULE__MD5_CFLAGS': '-I./Modules/_hacl/include -I./Modules/_hacl/internal '
+                       '-D_BSD_SOURCE -D_DEFAULT_SOURCE',
+ 'MODULE__MD5_DEPS': './Modules/hashlib.h \\ Modules/_hacl/Hacl_Hash_MD5.h '
+                     'Modules/_hacl/Hacl_Hash_MD5.c',
  'MODULE__MD5_STATE': 'yes',
+ 'MODULE__MULTIBYTECODEC_DEPS': './Modules/cjkcodecs/multibytecodec.h',
  'MODULE__MULTIBYTECODEC_STATE': 'yes',
  'MODULE__MULTIPROCESSING_CFLAGS': '-I./Modules/_multiprocessing',
  'MODULE__MULTIPROCESSING_STATE': 'yes',
@@ -853,15 +958,19 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__QUEUE_STATE': 'yes',
  'MODULE__RANDOM_STATE': 'yes',
  'MODULE__SCPROXY_STATE': 'n/a',
- 'MODULE__SHA1_DEPS': './Modules/hashlib.h',
+ 'MODULE__SHA1_CFLAGS': '-I./Modules/_hacl/include -I./Modules/_hacl/internal '
+                        '-D_BSD_SOURCE -D_DEFAULT_SOURCE',
+ 'MODULE__SHA1_DEPS': './Modules/hashlib.h \\ Modules/_hacl/Hacl_Hash_SHA1.h '
+                      'Modules/_hacl/Hacl_Hash_SHA1.c',
  'MODULE__SHA1_STATE': 'yes',
- 'MODULE__SHA256_DEPS': './Modules/hashlib.h',
- 'MODULE__SHA256_STATE': 'yes',
- 'MODULE__SHA3_DEPS': './Modules/_sha3/sha3.c ./Modules/_sha3/sha3.h '
-                      './Modules/hashlib.h',
+ 'MODULE__SHA2_CFLAGS': '-I./Modules/_hacl/include -I./Modules/_hacl/internal '
+                        '-D_BSD_SOURCE -D_DEFAULT_SOURCE',
+ 'MODULE__SHA2_DEPS': './Modules/hashlib.h \\ '
+                      'Modules/_hacl/libHacl_Hash_SHA2.a',
+ 'MODULE__SHA2_STATE': 'yes',
+ 'MODULE__SHA3_DEPS': './Modules/hashlib.h \\ Modules/_hacl/Hacl_Hash_SHA3.h '
+                      'Modules/_hacl/Hacl_Hash_SHA3.c',
  'MODULE__SHA3_STATE': 'yes',
- 'MODULE__SHA512_DEPS': './Modules/hashlib.h',
- 'MODULE__SHA512_STATE': 'yes',
  'MODULE__SIGNAL_LDFLAGS': '',
  'MODULE__SOCKET_DEPS': './Modules/socketmodule.h ./Modules/addrinfo.h '
                         './Modules/getaddrinfo.c ./Modules/getnameinfo.c',
@@ -889,7 +998,9 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__STRUCT_STATE': 'yes',
  'MODULE__SYMTABLE_LDFLAGS': '',
  'MODULE__TESTBUFFER_STATE': 'yes',
- 'MODULE__TESTCAPI_DEPS': './Modules/testcapi_long.h',
+ 'MODULE__TESTCAPI_DEPS': './Modules/_testcapi/testcapi_long.h '
+                          './Modules/_testcapi/parts.h '
+                          './Modules/_testcapi/util.h',
  'MODULE__TESTCAPI_STATE': 'yes',
  'MODULE__TESTCLINIC_STATE': 'yes',
  'MODULE__TESTIMPORTMULTIPLE_STATE': 'yes',
@@ -900,11 +1011,13 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__TKINTER_LDFLAGS': '-ltk8.6 -ltkstub8.6 -ltcl8.6 -ltclstub8.6',
  'MODULE__TKINTER_STATE': 'yes',
  'MODULE__TRACEMALLOC_LDFLAGS': '',
+ 'MODULE__TYPING_LDFLAGS': '',
  'MODULE__TYPING_STATE': 'yes',
  'MODULE__UUID_CFLAGS': '-I/usr/include/uuid',
  'MODULE__UUID_LDFLAGS': '-luuid',
  'MODULE__UUID_STATE': 'yes',
  'MODULE__WEAKREF_LDFLAGS': '',
+ 'MODULE__XXINTERPCHANNELS_STATE': 'yes',
  'MODULE__XXSUBINTERPRETERS_STATE': 'yes',
  'MODULE__XXTESTFUZZ_STATE': 'yes',
  'MODULE__ZONEINFO_STATE': 'yes',
@@ -913,12 +1026,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OPENSSL_INCLUDES': '',
- 'OPENSSL_LDFLAGS': '',
- 'OPENSSL_LIBS': '-lssl -lcrypto',
- 'OPENSSL_RPATH': '',
- 'OPT': '-DNDEBUG -g -fwrapv -O3 -Wall',
- 'OTHER_LIBTOOL_OPT': '',
+ 'OPT': '-DNDEBUG -g -O3 -Wall',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
  'PACKAGE_STRING': 0,
@@ -952,10 +1060,10 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_FOR_REGEN': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
- 'PY_BUILTIN_MODULE_CFLAGS': '-DNDEBUG -g -fwrapv -O3 -Wall -march=armv7-a '
-                             '-mfloat-abi=hard -mfpu=neon -O3 -pipe '
-                             '-fstack-protector-strong -fno-plt '
+ 'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha2,sha3,blake2"',
+ 'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -DNDEBUG -g -O3 -Wall '
+                             '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 '
+                             '-pipe -fstack-protector-strong -fno-plt '
                              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wformat -Werror=format-security         '
                              '-fstack-clash-protection -march=armv7-a '
@@ -972,9 +1080,9 @@ build_time_vars = {'ABIFLAGS': '',
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden  -I./Include/internal -I. '
                              '-I./Include -fPIC -DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-DNDEBUG -g -fwrapv -O3 -Wall -march=armv7-a -mfloat-abi=hard '
-              '-mfpu=neon -O3 -pipe -fstack-protector-strong -fno-plt '
-              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+ 'PY_CFLAGS': '-fno-strict-overflow -DNDEBUG -g -O3 -Wall -march=armv7-a '
+              '-mfloat-abi=hard -mfpu=neon -O3 -pipe -fstack-protector-strong '
+              '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
               '-Werror=format-security         -fstack-clash-protection '
               '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
               '-fstack-protector-strong -fno-plt -fexceptions         '
@@ -987,7 +1095,7 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_CFLAGS_NODIST': '-std=c11 -Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-DNDEBUG -g -fwrapv -O3 -Wall -march=armv7-a '
+ 'PY_CORE_CFLAGS': '-fno-strict-overflow -DNDEBUG -g -O3 -Wall -march=armv7-a '
                    '-mfloat-abi=hard -mfpu=neon -O3 -pipe '
                    '-fstack-protector-strong -fno-plt -fexceptions         '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
@@ -1007,7 +1115,7 @@ build_time_vars = {'ABIFLAGS': '',
                     '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'PY_CPPFLAGS': '-I. -I./Include',
  'PY_ENABLE_SHARED': 1,
- 'PY_FORMAT_SIZE_T': '"z"',
+ 'PY_HAVE_PERF_TRAMPOLINE': 0,
  'PY_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
                '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'PY_LDFLAGS_NODIST': '',
@@ -1017,8 +1125,8 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SQLITE_HAVE_SERIALIZE': 1,
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-DNDEBUG -g -fwrapv -O3 -Wall -march=armv7-a '
-                        '-mfloat-abi=hard -mfpu=neon -O3 -pipe '
+ 'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -DNDEBUG -g -O3 -Wall '
+                        '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
                         '-fstack-protector-strong -fno-plt '
                         '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                         '-Werror=format-security         '
@@ -1044,13 +1152,95 @@ build_time_vars = {'ABIFLAGS': '',
  'Py_SUNOS_VERSION': 0,
  'Py_TRACE_REFS': 0,
  'QUICKTESTOPTS': '-x test_subprocess test_io test_lib2to3 \\',
- 'READELF': 'readelf',
+ 'READELF': '@READELF@',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.11.8',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.12.3',
  'SCRIPTDIR': '/usr/lib',
+ 'SCRIPT_2TO3': 'build/scripts-3.12/2to3-3.12',
+ 'SCRIPT_IDLE': 'build/scripts-3.12/idle3.12',
+ 'SCRIPT_PYDOC': 'build/scripts-3.12/pydoc3.12',
  'SETPGRP_HAVE_ARG': 0,
- 'SHELL': '/bin/sh',
+ 'SHAREDMODS': 'Modules/array.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_asyncio.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_bisect.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_contextvars.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_csv.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_heapq.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_json.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_lsprof.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_opcode.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_pickle.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_queue.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_random.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_struct.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_xxsubinterpreters.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_xxinterpchannels.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_zoneinfo.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/audioop.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/math.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/cmath.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_statistics.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_datetime.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_decimal.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/binascii.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_bz2.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_lzma.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/zlib.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_dbm.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_gdbm.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/readline.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_md5.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_sha1.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_sha2.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_sha3.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_blake2.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/pyexpat.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_elementtree.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_codecs_cn.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_codecs_hk.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_codecs_iso2022.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_codecs_jp.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_codecs_kr.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_codecs_tw.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_multibytecodec.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/unicodedata.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_crypt.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/fcntl.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/grp.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/mmap.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/nis.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/ossaudiodev.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_posixsubprocess.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/resource.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/select.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_socket.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/spwd.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/syslog.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/termios.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_posixshmem.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_multiprocessing.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_ctypes.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_curses.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_curses_panel.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_sqlite3.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_ssl.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_hashlib.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_uuid.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_tkinter.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/xxsubtype.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_xxtestfuzz.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_testbuffer.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_testinternalcapi.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_testcapi.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_testclinic.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_testimportmultiple.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_testmultiphase.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_testsinglephase.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/_ctypes_test.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/xxlimited.cpython-312-arm-linux-gnueabihf.so '
+               'Modules/xxlimited_35.cpython-312-arm-linux-gnueabihf.so',
+ 'SHELL': '/bin/sh -e',
  'SHLIBS': '-ldl',
  'SHLIB_SUFFIX': '.so',
  'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
@@ -1073,11 +1263,11 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_VOID_P': 4,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-311-arm-linux-gnueabihf',
+ 'SOABI': 'cpython-312-arm-linux-gnueabihf',
  'SRCDIRS': 'Modules   Modules/_blake2   Modules/_ctypes   Modules/_decimal   '
-            'Modules/_decimal/libmpdec   Modules/_io   '
-            'Modules/_multiprocessing   Modules/_sha3   Modules/_sqlite   '
-            'Modules/_sre   Modules/_xxtestfuzz   Modules/cjkcodecs   '
+            'Modules/_decimal/libmpdec   Modules/_hacl   Modules/_io   '
+            'Modules/_multiprocessing   Modules/_sqlite   Modules/_sre   '
+            'Modules/_testcapi   Modules/_xxtestfuzz   Modules/cjkcodecs   '
             'Modules/expat   Objects   Parser   Programs   Python   '
             'Python/frozen_modules   Python/deepfreeze',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
@@ -1091,25 +1281,24 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.11.8 ./python -E',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.12.3 ./python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.11.8 ./python -E '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.12.3 ./python -E '
                './Tools/scripts/run_tests.py',
- 'TESTSUBDIRS': 'ctypes/test \\',
+ 'TESTSUBDIRS': 'idlelib/idle_test \\',
  'TESTTIMEOUT': 1200,
  'TEST_MODULES': 'yes',
  'THREAD_STACK_SIZE': 0,
  'TIMEMODULE_LIB': 0,
- 'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
  'TZPATH': '/usr/share/zoneinfo',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': './Tools/scripts/update_file.py',
+ 'UPDATE_FILE': './Tools/build/update_file.py',
  'USE_COMPUTED_GOTOS': 1,
- 'VERSION': '3.11',
+ 'VERSION': '3.12',
  'WASM_ASSETS_DIR': './usr',
- 'WASM_STDLIB': './usr/lib/python3.11/os.py',
+ 'WASM_STDLIB': './usr/lib/python3.12/os.py',
  'WHEEL_PKG_DIR': '',
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DECIMAL_CONTEXTVAR': 1,
@@ -1124,8 +1313,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python/src/Python-3.11.8',
- 'abs_srcdir': '/build/python/src/Python-3.11.8',
+ 'abs_builddir': '/build/python/src/Python-3.12.3',
+ 'abs_srcdir': '/build/python/src/Python-3.12.3',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
